@@ -524,7 +524,7 @@ init_ui (void)
 	}
 
 	/* package version */
-	buddy_set_text ("the-version-entry", popt_data.package_ver);
+	druid_data.version = popt_data.package_ver;
 
         /* init some ex-radio buttons */
 	m = gtk_menu_new ();
@@ -578,34 +578,20 @@ init_ui (void)
 					  NULL);
 	}
 
-	buddy_set_text ("desc-text",
-			"Description of Problem:\n\n\n"
-			"Steps to reproduce the problem:\n"
-			"1. \n"
-			"2. \n"
-			"3. \n\n"
-			"Actual Results:\n\n\n"
-			"Expected Results:\n\n\n"
-			"How often does this happen?\n\n\n"
-			"Additional Information:\n");
-
-	/* set the cursor at the beginning of the second line
-	 * in the description page, and crearte the lock tag
-	 * for the email review page */
+	/* crearte lock tag for the email review page */
 	{
-		GtkTextBuffer *desc_buffer, *email_buffer;
-		GtkTextIter iter;
+		GtkTextBuffer *email_buffer;
 		GtkTextTag *tag;
 
-		desc_buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (GET_WIDGET ("desc-text")));
-		gtk_text_buffer_get_iter_at_line (desc_buffer, &iter, 1);
-		gtk_text_buffer_place_cursor (desc_buffer, &iter);
-		/* Create the tag for locking the headers */
-		email_buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (GET_WIDGET ("email-text")));
+		email_buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW
+						(GET_WIDGET ("email-text")));
 		tag = gtk_text_buffer_create_tag (email_buffer, "lock_tag",
-						  "editable", FALSE, NULL);
-
+						"editable", FALSE, NULL);
 	}
+
+
+
+
 }
 
 GtkWidget *
