@@ -32,6 +32,42 @@
 #include <libgnomevfs/gnome-vfs-async-ops.h>
 #include <sys/types.h>
 
+#define TEXT_BUG_CRASH "Description of the crash:\n\n\n\
+Steps to reproduce the crash:\n\
+1. \n\
+2. \n\
+3. \n\n\
+Expected Results:\n\n\n\
+How often does this happen?\n\n\n\
+Additional Information:\n"
+
+#define TEXT_BUG_WRONG "Description of Problem:\n\n\n\
+Steps to reproduce the problem:\n\
+1. \n\
+2. \n\
+3. \n\n\
+Actual Results:\n\n\n\
+Expected Results:\n\n\n\
+How often does this happen?\n\n\n\
+Additional Information:\n"
+
+
+#define TEXT_BUG_I18N "Language:\n\n\
+Wrong text location:\n\
+Current text:\n\n\n\
+Expected text:\n\n\n\
+Additional Information:\n"
+
+
+#define TEXT_BUG_DOC "Language:\n\n\
+Documentation chapter/section:\n\
+Current text:\n\n\n\
+Expected text:\n\n\n\
+Additional Information:\n"
+
+#define TEXT_BUG_REQUEST "Please describe your feature request:\n\n"
+
+
 typedef enum {
 	CRASH_DIALOG,
 	CRASH_CORE,
@@ -145,6 +181,7 @@ typedef struct {
 	BugzillaProduct   *product;
 	BugzillaComponent *component;
 	char              *severity;
+	char		  *version;
 
 	GList *dlsources;
 	GList *dldests;
