@@ -166,9 +166,9 @@ on_druid_about_clicked (GtkWidget *button, gpointer data)
 	pixbuf = gdk_pixbuf_new_from_file(BUDDY_ICONDIR "/bug-buddy.png", NULL);
 	
 	about = gnome_about_new (_("Bug Buddy"), VERSION,
-				 "Copyright (C) 1999, 2000, 2001, 2002, Jacob Berkman\n"
-				 "Copyright 2000, 2001, 2002 Ximian, Inc.\n"
-				 "Copyright 2003 Fernando Herrera",
+				 "Copyright \xc2\xa9 1999-2002 Jacob Berkman\n"
+				 "Copyright \xc2\xa9 2000-2002 Ximian, Inc.\n"
+				 "Copyright \xc2\xa9 2003 Fernando Herrera",
 				 _("The graphical bug reporting tool for GNOME."),
 				 authors,
 				 documentors,
@@ -821,7 +821,10 @@ select_version (GSList *list, char *version)
 		gtk_option_menu_set_history (GTK_OPTION_MENU (GET_WIDGET ("the-version-menu")),
 					     g_slist_position (list, g_slist_find_custom (list, version, 
 											  (GCompareFunc)strcmp)));
-	} else {
+		return;
+	}
+	 
+	if (version) {
 		/* Try to found a A.B.X version */
 		char *xversion;
 
@@ -833,12 +836,15 @@ select_version (GSList *list, char *version)
 			gtk_option_menu_set_history (GTK_OPTION_MENU (GET_WIDGET ("the-version-menu")),
 						     g_slist_position (list, g_slist_find_custom (list, xversion, 
 												  (GCompareFunc)strcmp)));
-		} else 
-			gtk_option_menu_set_history (GTK_OPTION_MENU (GET_WIDGET ("the-version-menu")),
-						     g_slist_position (list, g_slist_find_custom (list, "unspecified", 
-												  (GCompareFunc)strcmp)));
+			g_free (xversion);
+			return;
+		}
 		g_free (xversion);
 	}
+
+	gtk_option_menu_set_history (GTK_OPTION_MENU (GET_WIDGET ("the-version-menu")),
+				     g_slist_position (list, g_slist_find_custom (list, "unspecified", 
+										  (GCompareFunc)strcmp)));
 }
 
 static void
@@ -1051,6 +1057,8 @@ on_druid_next_clicked (GtkWidget *w, gpointer data)
 		update_version_menu (product);
 		if (application)
 			select_version (product->versions, application->version);
+		else	
+			select_version (product->versions, "unspecified");
 
 		if (druid_data.bug_type == BUG_REQUEST)
 			select_severity (druid_data.product->bts->severities, "enhancement");
